Technical Approach

Technology Stack

Framework: React 18 + Vite

Fast development with hot reload

Drag & Drop: react-beautiful-dnd

Smooth task reordering

Styling: CSS Variables

Theme toggle support

Storage: localStorage + JSON

Export/import capability

Architecture Layers

Frontend: React + Vite SPA

useState/useReducer for state

State: Local with sync

Auto-save to localStorage

Data: Browser storage

No backend required

Keyboard Shortcuts

Enter=Add | Esc=Cancel | Ctrl+D=Dark | Ctrl+E=Export